@@ -154,6 +154,9 @@ class dbus_switchboard_gui (hildon.Program):
         self.write_xrefs()
         self.write_handlers()
         self.write_defaults()
+        # qole fix: write URIs
+        self.write_uri_defaults()
+        print "**saved**"
         self.saved = True
     def read_xref(self):
         print "**load xrefs**"
